Command¶ Qualified name: intranet.apps.dataimport.management.commands.update\_administrators.Command class intranet.apps.dataimport.management.commands.update_administrators.Command(stdout=None, stderr=None, no_color=False, force_color=False)[source]¶ Bases: BaseCommand Methods add_arguments handle resolve_administrator Returns the administrator to assign user, or None if it cannot be determined. Attributes help resolve_administrator(user: User, listed_name: str) → User | None[source]¶ Returns the administrator to assign user, or None if it cannot be determined.